@@ -73,7 +73,7 @@ private:
     QMap<QString, Device*> mDevices;
 
     // The Initializer object sets things up, and also does cleanup when it goes out of scope
-    QCA::Initializer init;
+    QCA::Initializer mQcaInitializer;
 
 };
 
